Package: protti
Title: Bottom-Up Proteomics and LiP-MS Quality Control and Data
        Analysis Tools
Version: 1.0.0
Authors@R: 
    c(person(given = "Jan-Philipp",
           family = "Quast",
           role = c("aut", "cre"),
           email = "jpquast.software@gmail.com",
           comment = c(ORCID = "0000-0003-2713-778X")),
	person(given = "Dina",
           family = "Schuster",
           role = c("aut"),
           email = "dina.schuster@outlook.com",
           comment = c(ORCID = "0000-0001-6611-8237")),
	person(given = "ETH Zurich",
           role = c("cph", "fnd")))
Description: Useful functions and workflows for proteomics quality control and data analysis of both limited proteolysis-coupled mass spectrometry (LiP-MS) (Feng et. al. (2014) <doi:10.1038/nbt.2999>) and regular bottom-up proteomics experiments. Data generated with search tools such as 'Spectronaut', 'MaxQuant' and 'Proteome Discover' can be easily used due to flexibility of functions.
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
biocViews:
Imports: rlang, dplyr, stringr, magrittr, data.table, janitor,
        progress, purrr, tidyr, ggplot2, forcats, tibble, plotly,
        ggrepel, utils, grDevices, curl, readr, lifecycle, httr,
        methods, R.utils, stats
RoxygenNote: 7.3.3
Suggests: testthat, covr, knitr, rmarkdown, shiny, r3dmol, proDA,
        limma, dendextend, pheatmap, heatmaply, furrr, future,
        parallel, seriation, drc, igraph, stringi, STRINGdb, iq,
        scales, farver, ggforce, xml2, jsonlite, missForest
Depends: R (>= 4.0)
URL: https://github.com/jpquast/protti,
        https://jpquast.github.io/protti/
BugReports: https://github.com/jpquast/protti/issues
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-01-14 00:28:05 UTC; jan-philippquast
Author: Jan-Philipp Quast [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-2713-778X>),
  Dina Schuster [aut] (ORCID: <https://orcid.org/0000-0001-6611-8237>),
  ETH Zurich [cph, fnd]
Maintainer: Jan-Philipp Quast <jpquast.software@gmail.com>
Repository: CRAN
Date/Publication: 2026-01-14 07:50:01 UTC
Built: R 4.6.0; ; 2026-04-26 20:42:56 UTC; unix
