# Generated by roxygen2: do not edit by hand

export(analyse_functional_network)
export(anova_protti)
export(assign_missingness)
export(assign_peptide_type)
export(barcode_plot)
export(calculate_aa_scores)
export(calculate_diff_abundance)
export(calculate_go_enrichment)
export(calculate_kegg_enrichment)
export(calculate_protein_abundance)
export(calculate_sequence_coverage)
export(calculate_treatment_enrichment)
export(correct_lip_for_abundance)
export(create_queue)
export(create_structure_contact_map)
export(create_synthetic_data)
export(diff_abundance)
export(drc_4p_plot)
export(extract_metal_binders)
export(fetch_alphafold_aligned_error)
export(fetch_alphafold_prediction)
export(fetch_chebi)
export(fetch_eco)
export(fetch_go)
export(fetch_interpro)
export(fetch_kegg)
export(fetch_metal_pdb)
export(fetch_mobidb)
export(fetch_pdb)
export(fetch_pdb_structure)
export(fetch_quickgo)
export(fetch_uniprot)
export(fetch_uniprot_proteome)
export(filter_cv)
export(find_peptide)
export(find_peptide_in_structure)
export(fit_drc_4p)
export(go_enrichment)
export(impute)
export(impute_randomforest)
export(kegg_enrichment)
export(map_peptides_on_structure)
export(median_normalisation)
export(network_analysis)
export(normalise)
export(parallel_create_structure_contact_map)
export(parallel_fit_drc_4p)
export(peptide_profile_plot)
export(peptide_type)
export(plot_drc_4p)
export(plot_peptide_profiles)
export(plot_pval_distribution)
export(predict_alphafold_domain)
export(pval_distribution_plot)
export(qc_charge_states)
export(qc_contaminants)
export(qc_cvs)
export(qc_data_completeness)
export(qc_ids)
export(qc_intensity_distribution)
export(qc_median_intensities)
export(qc_missed_cleavages)
export(qc_pca)
export(qc_peak_width)
export(qc_peptide_type)
export(qc_proteome_coverage)
export(qc_ranked_intensities)
export(qc_sample_correlation)
export(qc_sequence_coverage)
export(randomise_queue)
export(read_protti)
export(scale_protti)
export(sequence_coverage)
export(treatment_enrichment)
export(ttest_protti)
export(volcano_plot)
export(volcano_protti)
export(woods_plot)
import(dplyr)
import(ggplot2)
import(progress)
import(purrr)
import(stringr)
import(tidyr)
importFrom(R.utils,insert)
importFrom(curl,has_internet)
importFrom(data.table,fread)
importFrom(data.table,fwrite)
importFrom(dplyr,bind_cols)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,pull)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,ungroup)
importFrom(forcats,fct_inorder)
importFrom(forcats,fct_relevel)
importFrom(forcats,fct_reorder)
importFrom(forcats,fct_rev)
importFrom(ggrepel,geom_text_repel)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(httr,GET)
importFrom(httr,accept)
importFrom(httr,config)
importFrom(httr,content)
importFrom(httr,http_error)
importFrom(httr,http_status)
importFrom(httr,message_for_status)
importFrom(httr,modify_url)
importFrom(httr,timeout)
importFrom(janitor,clean_names)
importFrom(janitor,make_clean_names)
importFrom(magrittr,"%>%")
importFrom(methods,is)
importFrom(plotly,ggplotly)
importFrom(purrr,discard)
importFrom(purrr,flatten)
importFrom(purrr,keep)
importFrom(purrr,map)
importFrom(purrr,map2)
importFrom(purrr,map2_dbl)
importFrom(purrr,map2_df)
importFrom(purrr,map2_dfr)
importFrom(purrr,map_dbl)
importFrom(purrr,map_df)
importFrom(purrr,map_dfr)
importFrom(purrr,pluck)
importFrom(purrr,pmap)
importFrom(purrr,reduce)
importFrom(purrr,set_names)
importFrom(readr,read_csv)
importFrom(readr,read_tsv)
importFrom(readr,write_csv)
importFrom(readr,write_tsv)
importFrom(rlang,"!!")
importFrom(rlang,":=")
importFrom(rlang,.data)
importFrom(rlang,as_label)
importFrom(rlang,as_name)
importFrom(rlang,enquo)
importFrom(rlang,ensym)
importFrom(rlang,expr)
importFrom(rlang,new_formula)
importFrom(rlang,sym)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,p.adjust)
importFrom(stats,pnorm)
importFrom(stats,prcomp)
importFrom(stats,pt)
importFrom(stats,rlnorm)
importFrom(stats,rnbinom)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stringr,regex)
importFrom(stringr,str_count)
importFrom(stringr,str_detect)
importFrom(stringr,str_extract)
importFrom(stringr,str_extract_all)
importFrom(stringr,str_replace)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_sort)
importFrom(stringr,str_split)
importFrom(stringr,str_squish)
importFrom(stringr,str_sub)
importFrom(stringr,str_to_upper)
importFrom(tibble,as_tibble)
importFrom(tibble,column_to_rownames)
importFrom(tibble,rowid_to_column)
importFrom(tibble,rownames_to_column)
importFrom(tibble,tibble)
importFrom(tidyr,complete)
importFrom(tidyr,crossing)
importFrom(tidyr,drop_na)
importFrom(tidyr,nesting)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,separate)
importFrom(tidyr,unite)
importFrom(tidyr,unnest)
importFrom(utils,URLencode)
importFrom(utils,capture.output)
importFrom(utils,combn)
importFrom(utils,data)
importFrom(utils,download.file)
importFrom(utils,head)
importFrom(utils,packageVersion)
importFrom(utils,untar)
